@@ -1,6 +1,6 @@
 #' Given the identifier for a data object, return all metadata about the object.
 #' 
-#' @import RCurl plyr RJSONIO
+#' @import RCurl plyr jsonlite
 #' @export
 #' @param id The EOL data object identifier (character)
 #' @param usekey use your API key or not (TRUE or FALSE)
@@ -10,13 +10,13 @@
 #'    console.
 #' @details It's possible to return JSON or XML with the EOL API. However, 
 #' 		this function only returns JSON for now. 
-#' @return List or dataframe.
-#' @examples \dontrun{
+#' @return List or dataframe (default).
+#' @examples \donttest{
 #' eol_dataobjects(id="d72801627bf4adf1a38d9c5f10cc767f")
 #' eol_dataobjects(id="21929584")
 #' }
 
-eol_dataobjects <- function(id, returntype = 'list', usekey = TRUE, key = NULL, verbose=TRUE)
+eol_dataobjects <- function(id, returntype = 'data.frame', usekey = TRUE, key = NULL, verbose=TRUE)
 {
   url = 'http://www.eol.org/api/data_objects/1.0/'
 	key <- getkey(key, "eolApiKey")
@@ -24,12 +24,11 @@ eol_dataobjects <- function(id, returntype = 'list', usekey = TRUE, key = NULL,
 	key2 <- paste("?", paste(compact(usekey_), collapse="&"), sep="")
 	urlget <- paste(url, id, '.json', key2, sep="")
 	mssg(verbose, urlget)
-	searchresults <- fromJSON(urlget)
-	
-	if(returntype == 'list') { searchresults  } else
-		if(returntype == 'data.frame'){  
-			message("not sure how to parse this yet, sorry for the wait")
-			searchresults
-		} else  
-			stop("returntype must be one of 'list' or 'data.frame'")
-}
\ No newline at end of file
+  tt <- GET(urlget)
+  stop_for_status(tt)
+  res <- content(tt, as = "text")    
+  returntype <- match.arg(returntype, c('list','data.frame'))
+  if(returntype == 'list') { jsonlite::fromJSON(res, FALSE)  } else {
+    jsonlite::fromJSON(res)
+  }	
+}
