@@ -1,6 +1,6 @@
 #' Search for pages in EOL database using a taxonconceptID.
 #' 
-#' @import RCurl plyr RJSONIO assertthat
+#' @import RCurl plyr jsonlite assertthat
 #' @export
 #' @param taxonconceptID The taxonconceptID (numeric), which is also the page 
 #' 		number.
@@ -32,8 +32,8 @@
 #' @details It's possible to return JSON or XML with the EOL API. However, 
 #' 		this function only returns JSON for now. 
 #' @return JSON list object, or data.frame.
-#' @examples \dontrun{
-#' pageid <- eol_search('Pomatomus')$pageid[1]
+#' @examples \donttest{
+#' (pageid <- eol_search('Pomatomus')$pageid[1])
 #' (out <- eol_pages(taxonconceptID=pageid)$scinames)
 #' }
 
@@ -61,7 +61,7 @@ eol_pages <- function(taxonconceptID, iucn=FALSE, images=0, videos=0, sounds=0,
   tt <- getForm(urlget, .params = args, .opts = callopts)
   assert_that(attr(tt, "Content-Type")[[1]] == "application/json")
   assert_that(attr(tt, "Content-Type")[[2]] == "utf-8")
-  res <- RJSONIO::fromJSON(tt)
+  res <- jsonlite::fromJSON(tt, FALSE)
   
   scinames <- do.call(rbind.fill, lapply(res$taxonConcepts, data.frame, stringsAsFactors=FALSE))
   if(!is.null(scinames))
@@ -87,4 +87,4 @@ parseeoldata <- function(x, y){
     else
       ldply(tmp)
   }
-}
\ No newline at end of file
+}
