@@ -1,6 +1,6 @@
 #' Parse taxon names using the GBIF name parser.
 #' 
-#' @import httr plyr RJSONIO
+#' @import httr plyr jsonlite
 #' @param scientificname A character vector of scientific names.
 #' @return A \code{data.frame} containing fields extracted from parsed 
 #' taxon names. Fields returned are the union of fields extracted from
@@ -10,7 +10,7 @@
 #' \url{http://tools.gbif.org/nameparser/api.do}
 #' @seealso \code{\link{gni_parse}}
 #' @export
-#' @examples \dontrun{
+#' @examples \donttest{
 #' gbif_parse(scientificname='x Agropogon littoralis')
 #' gbif_parse(c('Arrhenatherum elatius var. elatius', 
 #'              'Secale cereale subsp. cereale', 'Secale cereale ssp. cereale',
@@ -22,10 +22,10 @@ gbif_parse <- function(scientificname) {
   tt <- POST(url,
             config=c(add_headers('Content-Type' = 
                                    'application/json')),
-            body=RJSONIO::toJSON(scientificname))
+            body=jsonlite::toJSON(scientificname))
   stop_for_status(tt)
   res <- content(tt)
   tmp <- do.call(rbind.fill, lapply(res, as.data.frame))
   names(tmp) <- tolower(names(tmp))
   tmp
-}
\ No newline at end of file
+}
