@@ -1,12 +1,13 @@
 #' Return all synonyms for a taxon name with a given id.
 #'
-#' @import XML RCurl RJSONIO plyr
+#' @import XML RCurl jsonlite plyr
+#' @export
+#' 
 #' @param id the taxon identifier code
 #' @param key Your Tropicos API key; loads from .Rprofile.
 #' @param callopts Further args passed on to httr::GET
 #' @return List or dataframe.
-#' @export
-#' @examples \dontrun{
+#' @examples \donttest{
 #' tp_synonyms(id = 25509881)
 #' }
 
@@ -18,7 +19,7 @@ tp_synonyms <- function(id, key = NULL, callopts=list())
   tmp <- GET(url, query=args, callopts)
   stop_for_status(tmp)
   tmp2 <- content(tmp, as = "text")
-  res <- fromJSON(tmp2)
+  res <- jsonlite::fromJSON(tmp2, FALSE)
 
   if(names(res[[1]])[[1]] == "Error"){
     nonedf <- data.frame(nameid="no syns found",scientificname="no syns found",scientificnamewithauthors="no syns found",family="no syns found",stringsAsFactors = FALSE)
