@@ -5,7 +5,7 @@ temp <- eol_dataobjects(id="d72801627bf4adf1a38d9c5f10cc767f", verbose=FALSE)
 
 test_that("eol_dataobjects returns the correct dimensions", {
 	expect_equal(length(temp), 8)
-	expect_equal(length(temp$dataObjects[[1]]), 22)
+	expect_equal(NCOL(temp$dataObjects), 22)
 })
 
 test_that("eol_dataobjects returns the correct class", {
