@@ -1,10 +1,10 @@
 # tests for itis_hierarchy fxn in taxize
 context("itis_hierarchy")
 
-one <- itis_hierarchy(tsn=180543)
+one <- itis_hierarchy(tsn=180543, verbose=FALSE)
 two <- itis_hierarchy(tsn=180543, "up", verbose=FALSE)
 three <- itis_hierarchy(tsn=180543, "down", verbose=FALSE)
-four <-itis_hierarchy(tsn=c(180543,41074,36616))
+four <-itis_hierarchy(tsn=c(180543,41074,36616), verbose=FALSE)
 
 test_that("itis_hierarchy returns the correct class", {
   expect_that(one, is_a("data.frame"))
