@@ -1,8 +1,8 @@
 # tests for itis_kingdomnames fxn in taxize
 context("itis_kingdomnames")
 
-one <- itis_kingdomnames(202385)
-two <- itis_kingdomnames(tsn=c(202385,183833,180543))
+one <- itis_kingdomnames(202385, verbose=FALSE)
+two <- itis_kingdomnames(tsn=c(202385,183833,180543), verbose=FALSE)
 
 test_that("itis_kingdomnames returns the correct value", {
   expect_that(one, matches("Animalia"))
@@ -20,5 +20,5 @@ test_that("itis_kingdomnames correctly suppresses a message", {
 })
 
 test_that("itis_kingdomnames returns empty character string when given nonsense", {
-  expect_that(nchar(itis_kingdomnames("stuff"))[[1]], equals(0))
+  expect_that(nchar(itis_kingdomnames("stuff", verbose=FALSE))[[1]], equals(0))
 })
\ No newline at end of file
