@@ -11,6 +11,6 @@ test_that("itis_refs returns the correct class", {
   expect_that(two[[1]], is_a("data.frame"))
 })
 
-test_that("itis_refs returns correct error when given nonsense", {
+test_that("itis_refs returns a message when verbose is TRUE", {
   expect_message(itis_refs(202385, verbose=TRUE))
 })
\ No newline at end of file
