@@ -6,7 +6,7 @@ df <- tpl_search(taxon = splist)
 
 test_that("tpl_search returns the correct value", {
 	expect_that(as.character(df[1,1]), matches("Heliathus"))
-	expect_that(as.character(df[4,8]), matches("occidentalis"))
+	expect_that(as.character(df[4,8]), matches("Platanus"))
 })
 
 test_that("tpl_search returns the correct class", {
